#
# spec file for package openafs
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#
#	TUNABLES
#

#
# define distribution and version
#

#distribution-definitions here

#kerberos5
# 0=MIT | 1=Heimdal
%define		option_heimdal		0

# clean build-root after build
%define		option_clean_buildroot	0

# build largefile fileserver
%define		option_largefile	1

# build authlibs
%define build_authlibs 1

# build modules
%define build_modules 1

# create PAM libraries
%define build_pamlibs 1

# run regen to create new configure script
%define run_regen 1

#
# auto-determined parameters
#
%define pamdir            /%{_lib}/security
%define libdir            %{_libdir}
%define libexecdir        %{_libdir}
%define bindir            %{_bindir}
%define sbindir           %{_sbindir}
%define includedir        %{_includedir}/openafs
%define mandir            %{_mandir}
%define afslogsdir        /var/log/openafs
%define sysconfdir        %{_sysconfdir}
%define afsconfdir        /etc/openafs/server
%define viceetcdir        /etc/openafs
%define vicecachedir	  /var/cache/openafs
%define afslocaldir       /var/lib/openafs

Name:           openafs

Version:        1.6.8
Release:        23.1
Summary:        OpenAFS Distributed File System
License:        IPL-1.0
Group:          System/Filesystems
Url:            http://www.openafs.org/
%if %{_vendor} == "suse" 
PreReq:         %insserv_prereq %fillup_prereq 
%endif

Source0:        openafs-%{version}-src.tar.bz2
Source1:        openafs-%{version}-doc.tar.bz2
Source2:        configure
Source3:        configure-libafs
Source10:       README.SuSE.openafs
Source11:       rc.afs-server
Source12:       rc.afs-client
Source13:       sysconfig.openafs-client
Source14:       sysconfig.openafs-server
Source16:       NEWS
Source18:       RELNOTES-%{version}
Source19:       ChangeLog
Source20:       kernel-source.build-modules.sh
Source55:       openafs.SuidCells
Source56:       openafs.CellAlias
Source57:       openafs.ThisCell
Source58:       openafs.cacheinfo
Source99:       openafs.changes
Patch1:         openafs-1.6.x.layout.patch
Patch2:         openafs-1.6.x.heimdal.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

#
#	GENERAL BuildRequires and Requires
#

%if %{_vendor} == "suse"
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  ncurses-devel
BuildRequires:  vim

 %if %{build_pamlibs}
BuildRequires:  pam-devel
  %endif

 %if %{option_heimdal}
BuildRequires:  heimdal-devel
  %define krb5_config /usr/lib/heimdal/bin/krb5-config
 %else
BuildRequires:  krb5-devel
   %define krb5_config /usr/lib/mit/bin/krb5-config
 %endif
 %if %{build_modules} 
BuildRequires:  kernel-source
BuildRequires:  kernel-syms
BuildRequires:  module-init-tools
 %endif
 %define ARCH %{_arch}
%endif

%if %{_vendor} == "mandriva" 
BuildRequires:  krb5-devel
  %define krb5_config /usr/bin/krb5-config
  %define build_modules 0
  %define ARCH %{_arch}
%endif

%if %{_vendor} == "redhat"
BuildRequires:  krb5-devel
  %define krb5_config /usr/kerberos/bin/krb5-config
  %define build_modules 0
  %define ARCH %{_arch}
  %if %{build_modules} 
BuildRequires:  kernel-devel
  %endif
%endif

%description  
AFS is a cross-platform distributed file system product pioneered at
Carnegie Mellon University and supported and developed as a product by
Transarc Corporation (now IBM Pittsburgh Labs). It offers a
client-server architecture for file sharing, providing location
independence, scalability, and transparent migration capabilities for
data.

In addition, among its features are authentication, encryption,
caching, disconnected operations, replication for higher availability
and load balancing, and ACLs.

Authors:
--------
    see http://www.openafs.org/credits.html

%package client
Summary:        OpenAFS File System Client
Group:          System/Filesystems
Requires:       %{name} = %{version}
Requires:       %{name}-docs = %{version}
Requires:       %{name}-krb5-mit = %{version}
Requires:       coreutils
Requires:       diffutils
Requires:       fillup
Requires:       grep
Requires:       sed

%description client
AFS is a cross-platform distributed file system product pioneered at
Carnegie Mellon University and supported and developed as a product by
Transarc Corporation (now IBM Pittsburgh Labs). It offers a
client-server architecture for file sharing, providing location
independence, scalability, and transparent migration capabilities for
data.

In addition, among its features are authentication, encryption,
caching, disconnected operations, replication for higher availability
and load balancing, and ACLs. This package contains the OpenAFS client.

Authors:
--------
    see http://www.openafs.org/credits.html


%package server
Summary:        OpenAFS File System Server
Group:          System/Filesystems
Requires:       %{name} = %{version}
Requires:       %{name}-docs = %{version}

%description server
AFS is a cross-platform distributed file system product pioneered at
Carnegie Mellon University and supported and developed as a product by
Transarc Corporation (now IBM Pittsburgh Labs). It offers a
client-server architecture for file sharing, providing location
independence, scalability, and transparent migration capabilities for
data.

In addition, among its features are authentication, encryption,
caching, disconnected operations, replication for higher availability
and load balancing, and ACLs. This package contains the static
libraries and header files needed to develop applications for OpenAFS.

Authors:
--------
    see http://www.openafs.org/credits.html


%package authlibs
Summary:        OpenAFS authentication shared libraries
Group:          Development/Libraries/C and C++

%if %{build_authlibs}
%description authlibs
The AFS distributed filesystem.  AFS is a distributed filesystem
allowing cross-platform sharing of files among multiple computers.
Facilities are provided for access control, authentication, backup and
administrative management.

This package provides a shared version of libafsrpc and libafsauthent.
None of the programs included with OpenAFS currently use these shared
libraries; however, third-party software that wishes to perform AFS
authentication may link against them.
%endif

%package authlibs-devel
Summary:        OpenAFS shared library development
Group:          Development/Libraries/C and C++
%if %{build_authlibs}
Requires:       %{name}-authlibs = %{version}
%endif
Requires:       %{name}-devel = %{version}

%description authlibs-devel
The AFS distributed filesystem.  AFS is a distributed filesystem
allowing cross-platform sharing of files among multiple computers.
Facilities are provided for access control, authentication, backup and
administrative management.

This package includes the static versions of libafsrpc and
libafsauthent, and symlinks required for building against the dynamic
libraries.


%package devel
Summary:        OpenAFS Static Libraries and Header Files
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}

%description devel
AFS is a cross-platform distributed file system product pioneered at
Carnegie Mellon University and supported and developed as a product by
Transarc Corporation (now IBM Pittsburgh Labs). It offers a
client-server architecture for file sharing, providing location
independence, scalability, and transparent migration capabilities for
data.

In addition, among its features are authentication, encryption,
caching, disconnected operations, replication for higher availability
and load balancing, and ACLs. This package contains the OpenAFS server.

Authors:
--------
    see http://www.openafs.org/credits.html


%package docs
Summary:        OpenAFS user and administrator documentation
Group:          System/Filesystems
Requires:       %{name} = %{version}

%description docs
The AFS distributed filesystem.  AFS is a distributed filesystem
allowing cross-platform sharing of files among multiple computers.
Facilities are provided for access control, authentication, backup and
administrative management.

This package provides HTML documentation for OpenAFS users and system
administrators.

%package kernel-source
Summary:        OpenAFS Kernel Module source tree
Group:          System/Filesystems
Requires:       bison
Requires:       flex
Requires:       gcc
Requires:       kernel-devel
Provides:       openafs-kernel = %{version}

%description kernel-source
The AFS distributed filesystem.  AFS is a distributed filesystem
allowing cross-platform sharing of files among multiple computers.
Facilities are provided for access control, authentication, backup and
administrative management.

This package provides the source code to build your own AFS kernel
module.

%if %{option_heimdal}
%package krb5-heimdal
Summary:        OpenAFS programs to use with krb5
Group:          System/Filesystems
Requires:       %{name} = %{version}
Requires:       heimdal-lib
Requires:       heimdal-tools

%description krb5-heimdal
The AFS distributed filesystem.  AFS is a distributed filesystem
allowing cross-platform sharing of files among multiple computers.
Facilities are provided for access control, authentication, backup and
administrative management.

This package provides compatibility programs so you can use krb5
to authenticate to AFS services, instead of using AFS's homegrown
krb4 lookalike services.
This is using the  implementation of krb5.
Requires:       heimdal-lib
Requires:       heimdal-tools
%else 

%package krb5-mit
Summary:        OpenAFS programs to use with krb5
Group:          System/Filesystems
Requires:       %{name} = %{version}
Requires:       krb5

%description krb5-mit
The AFS distributed filesystem.  AFS is a distributed filesystem
allowing cross-platform sharing of files among multiple computers.
Facilities are provided for access control, authentication, backup and
administrative management.

This package provides compatibility programs so you can use krb5
to authenticate to AFS services, instead of using AFS's homegrown
krb4 lookalike services.
This is using the MIT implementation of krb5.

%endif

%if %{build_modules}
%package KMP
Summary:        OpenAFS Distributed File System - kernel module
Group:          System/Kernel
%suse_kernel_module_package lockdep um

%description KMP
This package contains the kernel module for OpenAFS. For details see
the openafs package.

Authors:
--------
    see http://www.openafs.org/credits.html


%endif

%prep

: @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
: @@@
: @@@ package-name:       %{name}
: @@@ file-layout:	  fsh
: @@@ PAM modules dir:    %{pamdir}
: @@@ lib dir:    	  %{libdir}
: @@@ libexec dir:    	  %{libexecdir}
: @@@ bin dir:    	  %{bindir}
: @@@ sbin dir:    	  %{sbindir}
: @@@ include dir:    	  %{includedir}
: @@@ sysconf dir:    	  %{sysconfdir}
: @@@ man dir:    	  %{mandir}
: @@@ build modules:      %{build_modules}
%if %{option_heimdal}
: @@@ krb5 : heimdal
%else
: @@@ krb5 : mit
%endif
: @@@ ARCH:               %{ARCH}
: @@@ target cpu:         %{_target_cpu}
: @@@
: @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@

%setup -q -n openafs-%{version} -T -b 0 -b 1

cp src/config/param.s390_linux24.h src/config/param.s390_linux26.h

%patch1 -p1
%if %{option_heimdal}
%patch2 -p1
%endif

%if %{run_regen}
 ./regen.sh
%endif

%build
sysbase=%{ARCH}
%ifarch ppc
	perl -pi -e 's,^(XCFLAGS.*),\1 -fPIC,' src/config/Makefile.ppc_linux24.in
%endif
%ifarch ppc64
	sysbase=ppc64
%endif
%ifarch s390x
	sysbase=s390
%endif
%ifarch x86_64
	sysbase=amd64
	perl -pi -e 's,^(XCFLAGS.*),\1 -fPIC,' src/config/Makefile.amd64_linux24.in
	perl -pi -e 's,^(XLIBS.*),\1 -lresolv,' src/config/Makefile.amd64_linux24.in
%endif
afs_sysname=${sysbase}_linux26
# there are mixed static and shared libs, using -fPIC everywhere is the most safe.
#

RPM_OPT_FLAGS=`echo ${RPM_OPT_FLAGS} | sed s/-D_FORTIFY_SOURCE=2//`
export CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing -fPIC" 

%if %{option_heimdal}
export CFLAGS="$CFLAGS -I/usr/include/heimdal" 
%else
export KRB5LIBS='-lcom_err -lkrb5'
%endif

%ifarch ppc64
export LDFLAGS="$LDFLAGS -m64"
%endif

#
./configure \
		--prefix=/usr \
		--disable-transarc-paths \
%if %{build_pamlibs} == 0
               --disable-pam \
%endif
		--bindir=%{bindir} \
		--sbindir=%{sbindir} \
		--libdir=%{libdir} \
		--libexecdir=%{libexecdir} \
		--includedir=%{includedir} \
		--sysconfdir=%{sysconfdir} \
		--mandir=%{mandir} \
		--with-krb5-conf=%{krb5_config} \
%if %{option_largefile}
		--enable-largefile-fileserver \
%endif
		--with-afs-sysname=$afs_sysname \
		--disable-kernel-module

make CCFLAGS="$CFLAGS" XCFLAGS="$CFLAGS" PAM_CFLAGS="$CFLAGS" KOPTS="$CFLAGS" all_nolibafs
make CCFLAGS="$CFLAGS" XCFLAGS="$CFLAGS" PAM_CFLAGS="$CFLAGS" KOPTS="$CFLAGS" only_libafs_tree

# the test suite need a configured KDC
#make -C src/tests all

# Kernel-module

%if %{build_modules}
mkdir obj

for flavor in %flavors_to_build; do
    rm -rf obj/$flavor
    cp -a libafs_tree obj/$flavor
    pushd obj/$flavor
    ./configure  --with-linux-kernel-build=/usr/src/linux-obj/%{ARCH}/$flavor --with-linux-kernel-headers=/usr/src/linux \
		--disable-transarc-paths
    make
    popd
done
%endif

%install
if [ -n "$RPM_BUILD_ROOT" ] ; then
   [ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT
fi

#
mkdir ${RPM_BUILD_ROOT}
#
mkdir $RPM_BUILD_ROOT/etc
mkdir -p  $RPM_BUILD_ROOT/etc/init.d/
mkdir -p  $RPM_BUILD_ROOT/%{libdir}/
mkdir -p  $RPM_BUILD_ROOT/%{includedir}
mkdir -p  $RPM_BUILD_ROOT/%{afslogsdir}
mkdir -p  $RPM_BUILD_ROOT/%{mandir}
%if %{build_pamlibs}
mkdir -p %{buildroot}/%{pamdir}
%endif
mkdir -p %{buildroot}/%{bindir}
make DESTDIR=$RPM_BUILD_ROOT install_nolibafs
# config & startup files
install -m 755 $RPM_SOURCE_DIR/rc.afs-server $RPM_BUILD_ROOT/etc/init.d/openafs-server
install -m 755 $RPM_SOURCE_DIR/rc.afs-client $RPM_BUILD_ROOT/etc/init.d/openafs-client
ln -s ../../etc/init.d/openafs-server $RPM_BUILD_ROOT/usr/sbin/rcopenafs-server
ln -s ../../etc/init.d/openafs-client $RPM_BUILD_ROOT/usr/sbin/rcopenafs-client

#
# generate man-pages 

OLD_PWD=`pwd`
cd doc/man-pages
make DESTDIR=$RPM_BUILD_ROOT install
cd $OLD_PWD

#
#	common: pam, kpasswd

# conflicts with kpasswd from heimdal package
mv $RPM_BUILD_ROOT/usr/bin/kpasswd $RPM_BUILD_ROOT/usr/bin/afs_kpasswd
mv $RPM_BUILD_ROOT/%{mandir}/man1/kpasswd.1 $RPM_BUILD_ROOT/%{mandir}/man1/afs_kpasswd.1
%if %{build_pamlibs}
  mv %{buildroot}/%{libdir}/pam* %{buildroot}/%{pamdir}
  ln -sf pam_afs.so.1	%{buildroot}/%{pamdir}/pam_afs.so
  ln -sf pam_afs.krb.so.1	%{buildroot}/%{pamdir}/pam_afs.krb.so
%endif

#	common: kernel-source 
mkdir -p $RPM_BUILD_ROOT/usr/src/kernel-modules/openafs
chmod -R o-w src/libafs
chmod -R o-w libafs_tree

#	common: KMP
%if %{build_modules}
  export INSTALL_MOD_PATH=$RPM_BUILD_ROOT
  export INSTALL_MOD_DIR=updates

  for flavor in %flavors_to_build; do
    make -C /usr/src/linux-obj/%{ARCH}/$flavor modules_install \
         M=$PWD/`find obj/$flavor/ -name MODLOAD-\* -type d`
  done
%endif

# kernel-sources
cp -a libafs_tree $RPM_BUILD_ROOT/usr/src/kernel-modules/openafs
cp -av %{S:20} $RPM_BUILD_ROOT/usr/src/kernel-modules/openafs/build-modules.sh
install -m 644 src/LICENSE $RPM_BUILD_ROOT/usr/src/kernel-modules/openafs/LICENSE
#%{_sourcedir}/fdupes -q -r -s $RPM_BUILD_ROOT/usr/src/kernel-modules

# main package
mkdir -p $RPM_BUILD_ROOT/%{mandir}/man5
install -m 644 src/pam/pam_afs.5 $RPM_BUILD_ROOT/%{mandir}/man5
cp -a %{S:10} README.SuSE
cp -a %{S:16} NEWS
cp -a %{S:18} RELNOTES
cp -a %{S:19} ChangeLog

# devel package
#%{_sourcedir}/fdupes -q -r -s $RPM_BUILD_ROOT/usr/include/openafs
#%{_sourcedir}/fdupes -q -r -s $RPM_BUILD_ROOT/usr/%{libdir}/openafs
#%{_sourcedir}/fdupes -q -r -s $RPM_BUILD_ROOT/usr/src/kernel-modules/openafs

# krb5
mv $RPM_BUILD_ROOT%{bindir}/asetkey $RPM_BUILD_ROOT%{sbindir}/asetkey

mv $RPM_BUILD_ROOT%{bindir}/bos $RPM_BUILD_ROOT%{sbindir}/bos
mv $RPM_BUILD_ROOT%{bindir}/udebug $RPM_BUILD_ROOT%{sbindir}/udebug

# avoid conflict with scout
mv $RPM_BUILD_ROOT/usr/bin/scout $RPM_BUILD_ROOT/usr/bin/afs_scout
mv $RPM_BUILD_ROOT/%{_mandir}/man1/scout.1 $RPM_BUILD_ROOT/%{_mandir}/man1/afs_scout.1

# remove unused man pages
for x in afs_ftpd afs_inetd afs_login afs_rcp afs_rlogind afs_rsh \
    dkload knfs package runntp symlink symlink_list symlink_make \
    symlink_remove; do
        rm -f $RPM_BUILD_ROOT%{mandir}/man1/${x}.1
done

# compress man pages
OLD_PWD=`pwd`
for d in $RPM_BUILD_ROOT%{_mandir}/man*;do
    cd $d
    for f in *;do
        if [ -h $f ]; then
            mv $f $f.gz
        elif [ -f $f ];then
            gzip -9 $f
        else 
            echo "Unknown thing to compress : $f"
        fi
    done
done

cd $OLD_PWD

# move  %{libdir}/afs-stuff to %{libdir}/openafs
mv $RPM_BUILD_ROOT/%{libdir}/afs/* $RPM_BUILD_ROOT/%{libdir}/openafs
rm -rf $RPM_BUILD_ROOT/%{libdir}/afs

#
# prepare some directories
mkdir -p $RPM_BUILD_ROOT/var/adm/fillup-templates
mkdir -p $RPM_BUILD_ROOT/%{vicecachedir}
mkdir -p $RPM_BUILD_ROOT/%{viceetcdir}
mkdir -p $RPM_BUILD_ROOT/usr/share/openafs/C
mkdir -p $RPM_BUILD_ROOT/%{afsconfdir}
mkdir -p $RPM_BUILD_ROOT/%{afslocaldir}
mkdir -p $RPM_BUILD_ROOT/afs
cp -a src/afsd/CellServDB $RPM_BUILD_ROOT%{viceetcdir}/CellServDB
cp -a %{S:55} $RPM_BUILD_ROOT%{viceetcdir}/SuidCells
cp -a %{S:56} $RPM_BUILD_ROOT%{viceetcdir}/CellAlias
cp -a %{S:57} $RPM_BUILD_ROOT%{viceetcdir}/ThisCell
cp -a %{S:58} $RPM_BUILD_ROOT%{viceetcdir}/cacheinfo
cp -a src/afs/afszcm.cat $RPM_BUILD_ROOT/usr/share/openafs/C
install -m 644 %{S:13} $RPM_BUILD_ROOT/var/adm/fillup-templates/sysconfig.openafs-client
install -m 644 %{S:14} $RPM_BUILD_ROOT/var/adm/fillup-templates/sysconfig.openafs-server

#
# general cleanup
#

# it's already in /usr/bin
rm -f $RPM_BUILD_ROOT/usr/sbin/kpwvalid
# we supposedly don't need this one on linux
rm -f $RPM_BUILD_ROOT/usr/sbin/rmtsysd
rm -f $RPM_BUILD_ROOT/usr/share/man/man8/rmtsysd.8.gz
%if %{build_authlibs} == 0
 rm -f $RPM_BUILD_ROOT/%{libdir}/openafs/libafsauthent.so.*
 rm -f $RPM_BUILD_ROOT/%{libdir}/openafs/libafsrpc.so.*
 rm -f $RPM_BUILD_ROOT/%{libdir}/openafs/libkopenafs.so.*
 rm -f $RPM_BUILD_ROOT/%{libdir}/openafs/libafsauthent.a
 rm -f $RPM_BUILD_ROOT/%{libdir}/openafs/libafsauthent_pic.a
 rm -f $RPM_BUILD_ROOT/%{libdir}/openafs/libafsrpc.a
 rm -f $RPM_BUILD_ROOT/%{libdir}/openafs/libafsrpc_pic.a
 rm -f $RPM_BUILD_ROOT/%{libdir}/openafs/libkopenafs.a
 rm -f $RPM_BUILD_ROOT/%{libdir}/openafs/libafsauthent.so
 rm -f $RPM_BUILD_ROOT/%{libdir}/openafs/libafsrpc.so
 rm -f $RPM_BUILD_ROOT/%{libdir}/openafs/libkopenafs.so
%endif

%clean
%if %{option_clean_buildroot}
if [ -n "$RPM_BUILD_ROOT" ] ; then
	[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT
fi
%endif

%post kernel-source
echo To install the kernel-module, do:
echo cd /usr/src/kernel-modules/openafs
echo ./build-modules.sh build
echo ./build-modules.sh install

%post client
/sbin/ldconfig
%{fillup_and_insserv -n openafs-client}

if [ "x$1" = "x" ]; then
   my_operation=0
else
   my_operation=$1
fi
if [ $my_operation -gt 1 ]; then
    echo Not stopping the possibly running client.
    echo You must restart the client to put the upgrade into effect.
else 
    echo For configuring the client, please check /etc/sysconfig/openafs-client
    echo and/or follow the instructions found on http://www.openafs.org  how to install an openafs-client. 
fi

%preun client
%{stop_on_removal}

%postun client
%{insserv_cleanup}
/sbin/ldconfig

%post server
if [ "x$1" = "x" ]; then
   my_operation=0
else
   my_operation=$1
fi
if [ $my_operation -gt 1 ]; then
    echo Not stopping the possibly running services.
    echo You must restart the service to put the upgrade into effect.
else 
    echo For configuring the server, please check /etc/sysconfig/openafs-server
    echo and/or follow the instructions found on http://www.openafs.org to install an openafs-client. 
fi
%{fillup_and_insserv -n openafs-server}

%preun server
%{stop_on_removal}

%postun server
%{insserv_cleanup}

%postun devel
/sbin/ldconfig

%post devel
/sbin/ldconfig

%post authlibs
/sbin/ldconfig

%postun authlibs
/sbin/ldconfig

#
#	FILES
#

%files           
%defattr(-,root,root)
%{bindir}/afsmonitor
%{bindir}/afs_compile_et
%{bindir}/afs_kpasswd
%{bindir}/afs_scout
%{bindir}/sys
%{bindir}/translate_et
%{bindir}/xstat_cm_test
%{bindir}/xstat_fs_test
%{sbindir}/backup
%{sbindir}/butc
%{sbindir}/fms
%{bindir}/pts
%{sbindir}/kas
%{sbindir}/kdb
%{sbindir}/vos
%{sbindir}/bos
%{bindir}/afsio
%{bindir}/fs
%{sbindir}/udebug
%{sbindir}/state_analyzer 
%{sbindir}/salvsync-debug 
%{sbindir}/fssync-debug 
%{sbindir}/dafssync-debug
%{sbindir}/read_tape
%{bindir}/restorevol
%{sbindir}/rxdebug
%{sbindir}/uss
%{sbindir}/vsys
%dir %{viceetcdir}
%config(noreplace) %{viceetcdir}/CellServDB

%files    docs   
%defattr(-,root,root)
%doc %{mandir}/man1/*
%doc %{mandir}/man5/*
%doc %{mandir}/man8/*
%doc NEWS README* RELNOTES ChangeLog

%files client
%defattr(-,root,root)
 %{bindir}/cmdebug
 %{bindir}/klog
 %{bindir}/klog.krb
 %{bindir}/unlog
 %{bindir}/klog.krb5
 %{bindir}/up
 %{sbindir}/afsd
 %{sbindir}/fstrace
 %{bindir}/kpwvalid
 %{bindir}/pagsh
 %{bindir}/pagsh.krb	
 %{sbindir}/ka-forwarder
 %{bindir}/tokens
 %{bindir}/tokens.krb
%if %{build_pamlibs}
 %{pamdir}/pam_afs.krb.so.1
 %{pamdir}/pam_afs.krb.so
 %{pamdir}/pam_afs.so.1
 %{pamdir}/pam_afs.so
%endif
/etc/init.d/openafs-client
%dir /usr/share/openafs
%dir /usr/share/openafs/C
/usr/share/openafs/C/afszcm.cat
%config(noreplace) %{viceetcdir}/SuidCells
%config(noreplace) %{viceetcdir}/CellAlias
%config(noreplace) %{viceetcdir}/ThisCell
%config(noreplace) %{viceetcdir}/cacheinfo
/usr/sbin/rcopenafs-client
/var/adm/fillup-templates/sysconfig.openafs-client
/%{vicecachedir}
%ghost /afs

%files server 
%defattr(-,root,root)
%config /etc/init.d/openafs-server
%{_sbindir}/rcopenafs-server
%attr(770,root,root) %dir %{afslocaldir}
%attr(775,root,root) %dir %{afslogsdir}
%{sbindir}/voldump
%{bindir}/knfs
%config %{viceetcdir}/server
/var/adm/fillup-templates/sysconfig.openafs-server
%dir %{libdir}/openafs
 %{libdir}/openafs/ptserver
 %{libdir}/openafs/kaserver
 %{libdir}/openafs/salvager
 %{libdir}/openafs/vlserver
 %{libdir}/openafs/fileserver
 %{libdir}/openafs/buserver
 %{libdir}/openafs/upclient
 %{libdir}/openafs/upserver
 %{libdir}/openafs/volserver
 %{libdir}/openafs/dafileserver
 %{libdir}/openafs/davolserver
 %{libdir}/openafs/dasalvager
 %{libdir}/openafs/salvageserver
 %{sbindir}/bosserver
 %{sbindir}/kadb_check
 %{sbindir}/prdb_check
 %{sbindir}/volinfo
 %{sbindir}/vldb_convert
 %{sbindir}/vldb_check
 %{sbindir}/bos_util
 %{sbindir}/pt_util

%files devel  
%defattr(-,root,root)
 %{includedir}
 %dir %{libdir}/openafs
 %{libdir}/openafs/libacl.a
 %{libdir}/openafs/libafscp.a
 %{libdir}/openafs/libafsadminutil.a
 %{libdir}/openafs/libafsint.a
 %{libdir}/openafs/libafsutil.a
 %{libdir}/openafs/libaudit.a
 %{libdir}/openafs/libauth.a
 %{libdir}/openafs/libauth.krb.a
 %{libdir}/openafs/libbos.a
 %{libdir}/openafs/libbosadmin.a
 %{libdir}/openafs/libbubasics.a
 %{libdir}/openafs/libbudb.a
 %{libdir}/openafs/libbutm.a
 %{libdir}/openafs/libbxdb.a
 %{libdir}/openafs/libcfgadmin.a
 %{libdir}/openafs/libclientadmin.a
 %{libdir}/openafs/libcmd.a
 %{libdir}/openafs/libafscom_err.a
 %{libdir}/openafs/libdes.a
 %{libdir}/openafs/libdir.a
 %{libdir}/openafs/libfsprobe.a
 %{libdir}/openafs/libgtx.a
 %{libdir}/openafs/libjuafs.a
 %{libdir}/openafs/libkasadmin.a
 %{libdir}/openafs/libkauth.a
 %{libdir}/openafs/libkauth.krb.a
 %{libdir}/openafs/liblwp.a
 %{libdir}/openafs/libprocmgmt.a
 %{libdir}/openafs/libprot.a
 %{libdir}/openafs/libptsadmin.a
 %{libdir}/openafs/librx.a
 %{libdir}/openafs/librxkad.a
 %{libdir}/openafs/librxstat.a
 %{libdir}/openafs/libsys.a
 %{libdir}/openafs/libuafs.a
 %{libdir}/openafs/libubik.a
 %{libdir}/openafs/libusd.a
 %{libdir}/openafs/libvldb.a
 %{libdir}/openafs/libvlib.a
 %{libdir}/openafs/libvolser.a
 %{libdir}/openafs/libvosadmin.a
 %{libdir}/openafs/libxstat_cm.a
 %{libdir}/openafs/libxstat_fs.a
 %{libdir}/openafs/util.a
 %{libdir}/openafs/vlib.a
%{bindir}/livesys
%{bindir}/rxgen

%files    kernel-source 
%defattr(-,root,root)
%dir /usr/src/kernel-modules
%dir /usr/src/kernel-modules/openafs
/usr/src/kernel-modules/openafs/*

%if %{option_heimdal}
%files krb5-heimdal
%else 
%files krb5-mit
%endif
%defattr(-,root,root)
%{bindir}/aklog
%{sbindir}/asetkey

%if %{build_authlibs}
%files authlibs
%defattr(-,root,root)
%{libdir}/openafs/libafsauthent.so.*
%{libdir}/openafs/libafsrpc.so.*
%{libdir}/openafs/libkopenafs.so.*

%files authlibs-devel
%defattr(-,root,root)
%{libdir}/openafs/libafsauthent.a
%{libdir}/openafs/libafsauthent_pic.a
%{libdir}/openafs/libafsrpc.a
%{libdir}/openafs/libafsrpc_pic.a
%{libdir}/openafs/libkopenafs.a
%{libdir}/openafs/libafsauthent.so
%{libdir}/openafs/libafsrpc.so
%{libdir}/openafs/libkopenafs.so
%endif

#
#	CHANGELOG
#

%changelog
* Thu Jun 17 2010 cseader@novell.com
- update to version 1.4.12.1
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 nadvornik@suse.cz
- fixed kernel module to compile
* Wed Jan 11 2006 mge@suse.de
- add openafs.SuidCells and openafs.CellServDB
- cleanup SPEC-file(s)
- finally adopt
  sysconfig.transarcmode.openafs-client
  rc.transarcmode.afs-server
  rc.transarcmode.afs-client
  to transarc mode; and fix a small typo in
  rc.defaultmode.afs-client
* Fri Jan  6 2006 mge@suse.de
- set "%%defattr(-,root,root)" for transarcmode-file-lists
- fix lib64 build problem in transarcmode
* Thu Jan  5 2006 mge@suse.de
- introduce transarc-mode and default-mode
- introduce "options"
* Thu Dec 29 2005 mge@suse.de
- build for SLES 9
- with heimdal krb5 support
- enable-largefile-fileserver
* Wed Dec 21 2005 nadvornik@suse.cz
- updated to 1.4.0
- fixed dangerous compiler warnings
* Mon Oct 31 2005 dmueller@suse.de
- don't build as root
* Fri Aug 26 2005 nadvornik@suse.cz
- fixed kernel module to build
- fixed sysconfig file name
* Thu Jul 14 2005 nadvornik@suse.cz
- updated to 1.3.85
- used LSB conforming init script names
* Tue Jul  5 2005 hare@suse.de
- Update for linux 2.6.13.
* Thu May 12 2005 nadvornik@suse.cz
- gcc4 fixes in kernel module
* Tue Apr 12 2005 nadvornik@suse.cz
- fixed to compile with gcc4
* Wed Feb 23 2005 nadvornik@suse.cz
- fixed memory leaks and 64bit fixes backported from 1.3.79
- updated README.SUSE
* Thu Feb  3 2005 nadvornik@suse.cz
- updated to 1.3.78
* Mon Jan 31 2005 nadvornik@suse.cz
- fixed afs.h to be usable from userspace [#50283]
* Tue Jan 25 2005 nadvornik@suse.cz
- updated to latest snapshot
* Wed Sep 15 2004 nadvornik@suse.cz
- added requres: kernel-nongpl [#45167]
- fixed kernel module oops [#44618]
* Wed Aug 11 2004 nadvornik@suse.cz
- use kernel module from openafs 1.3.70 to support kernel 2.6
* Mon Mar  8 2004 nadvornik@suse.cz
- updated to 1.2.11
- added note that client for kernel 2.6 is not available
* Tue Jan 20 2004 ro@suse.de
- added pam-devel to neededforbuild
* Fri Dec 12 2003 meissner@suse.de
- Added hack if no MTU came from userspace.
- Removed superflous ppc64 patch part.
* Thu Dec 11 2003 meissner@suse.de
- ppc64 port added (status: no longer crashes, talks to the network,
  but not successfully).
- Change headerfiles to make it possible to do a ppc -> ppc64 crosscompile.
* Mon Oct  6 2003 olh@suse.de
- build with -fPIC on ppc32
* Tue Sep 16 2003 nadvornik@suse.cz
- patch from cvs to use AllocLargeSpace for struct osi_file to prevent
  oopses with some kernel configurations
* Thu Sep 11 2003 nadvornik@suse.cz
- added option DYNROOT to sysconfig and enabled it by default [#27205]
* Wed Sep 10 2003 nadvornik@suse.cz
- added cleanup before module build [#29649]
* Tue Sep  9 2003 nadvornik@suse.cz
- fixed possible segfault
* Thu Sep  4 2003 nadvornik@suse.cz
- set permissions of /var/lib/openafs to 700
- README.SuSE fixes
* Thu Aug 28 2003 nadvornik@suse.cz
- use ghost for /afs, the directory is created by init-script
- fixed README.SuSE
* Thu Aug 21 2003 nadvornik@suse.cz
- moved all static libraries to /usr/lib/afs, fixes conflict with libdes
- used default value for THIS_CELL_SERVER_NAME
- removed old patches
* Tue Aug 12 2003 nadvornik@suse.cz
- fixed a bug in init script
* Mon Aug 11 2003 nadvornik@suse.cz
- updated to final 1.2.10
* Wed Jul 30 2003 nadvornik@suse.cz
- updated to 1.2.10-rc4
- do not destroy CellServDB even if REGENERATE_CELL_INFO=yes
- fixed to compile on x86_64
* Wed Jul 30 2003 sf@suse.de
-  use %%_lib where it was missing
* Wed Jul  9 2003 nadvornik@suse.cz
- fixed conflicts in filelist
* Fri Jun 20 2003 nadvornik@suse.cz
- improved init scripts
* Thu Jun 19 2003 nadvornik@suse.cz
- added README.SuSE
- fixed init scripts [#27426]
- installed man pages
* Thu Jun 12 2003 poeml@suse.de
- add /usr/src/kernel-modules to the file list
* Wed Jun  4 2003 schwab@suse.de
- Fix SMP configuration detection.
* Wed May 14 2003 poeml@suse.de
- rework filelists:
  - package/remove unpackaged files
  - move some files into the server & client subpackages
  - use %%defattr
- fix deprecated tail -1 syntax (fixes building the kernel module)
* Mon May 12 2003 nadvornik@suse.cz
- updated to 1.2.9
- added DATA_ENCRYPTION option to sysconfig
* Mon Mar 10 2003 poeml@suse.de
- x86_64: add -lresolv, -fPIC
- fix lib path on all 64 bit platforms
* Thu Mar  6 2003 nadvornik@suse.cz
- added sysconfig metadata
* Mon Feb 24 2003 nadvornik@suse.cz
- added dirs /afs, /etc/openafs, /var/lib/openafs to filelist
* Sun Feb 16 2003 olh@suse.de
- workaround broken -lresolv detection, lib64 fixes
* Wed Feb 12 2003 nadvornik@suse.cz
- fixed multiline strings in kernel module
* Fri Jan 24 2003 nadvornik@suse.cz
- updated to 1.2.8
- improved init script
* Fri Nov 29 2002 nadvornik@suse.cz
- included errno.h
- fixed multiline strings
* Fri Nov 22 2002 nadvornik@suse.cz
- first version of init scripts
* Wed Nov 20 2002 poeml@suse.de
- initial draft of a package. Lots of stuff missing, like init
  scripts, or the kerberos 5 migration toolkit.
